@@ -200,6 +200,6 @@ useShinydashboardPlus <- function() {
     sidebar = shinydashboard::dashboardSidebar(),
     body = shinydashboard::dashboardBody()
   ))
-  attachDependencies(tags$div(), value = deps)
+  attachDependencies(tags$div(class = "main-sidebar", style = "display: none;"), value = deps)
 }
 
