@@ -23,6 +23,14 @@ var VerticalTabInputBinding = new Shiny.InputBinding();
 
       if (data.hasOwnProperty('value')) {
         $el.find("[data-value='" + data.value + "']").click();
+      }else if(data.hasOwnProperty('validate')){
+        if($el.children(".active").length === 0 && $el.children().length > 0){
+          $el.children().last().click();
+        }
+      }else if(data.hasOwnProperty('reorder')){
+        items = $el.children();
+        items.detach();
+        $el.append( $.map(data.reorder, function(v){ return items[v - 1] }) );
       }
 
     },
